package Task::CryptoExchange::API;

our $DATE = '2018-01-09'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Modules that interface to cryptocurrency exchanges

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::CryptoExchange::API - Modules that interface to cryptocurrency exchanges

=head1 VERSION

version 0.002

=head1 TASK CONTENTS

=head2 Included modules

#CODE: for (`acme-cpanlists ls-entries "Modules that interface to cryptocurrency exchanges"`) { print "=pkg $_\n" }

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
